import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.*;

public class HamletParserTest {
    private String hamletText;
    private HamletParser hamletParser;

    String hamletRegex;
    String horatioRegex;

    @Before
    public void setUp() {
        this.hamletParser = new HamletParser();
        this.hamletText = hamletParser.getHamletData();

        this.hamletRegex = "(HAMLET|Hamlet)";
        this.horatioRegex = "(HORATIO|Horatio)";
    }

    @Test
    public void testChangeHamletToLeon() {
        //When
        int hamlet = hamletParser.wordCounter(hamletRegex);
        hamletParser.findAndReplace(hamletRegex, "Leon");
        int leon = hamletParser.wordCounter("Leon");

        //Expect
        int expect = hamlet;

        //Actual
        int actual = leon;

        Assert.assertEquals(expect,actual);
        Assert.assertTrue(hamletParser.wordCounter(hamletRegex) == 0);
    }

    @Test
    public void testChangeHoratioToTariq() {
        //When
        int horatio = hamletParser.wordCounter(horatioRegex);
        hamletParser.findAndReplace(horatioRegex, "Tariq");
        int tariq = hamletParser.wordCounter("Tariq");

        //Expect
        int expect = horatio;

        //Actual
        int actual = tariq;

        Assert.assertEquals(expect, actual);
        Assert.assertTrue(hamletParser.wordCounter(horatioRegex) == 0);
    }

    @Test
    public void testFindHoratio() {
        //Expected
        int expected = 158;

        //Actual
        int actual = hamletParser.wordCounter(horatioRegex);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testFindHamlet() {
        //Expected
        int expected = 472;

        //Actual
        int actual = hamletParser.wordCounter(hamletRegex);

        Assert.assertEquals(expected, actual);
    }
}